<?php
/**
 * @category    Pinpoint
 * @package     Pinpoint_RegisterOnSuccess
 * @copyright   Copyright (c) 2019 Pinpoint Designs. (http://www.pinpointdesigns.co.uk)
 * @author      Mohamed Zahran <mohamed.zahran@bytology.co.uk>
 */

namespace Pinpoint\RegisterOnSuccess\Plugin;

use Magento\Customer\Controller\Account\CreatePost;

/**
 * Class NewCustomer
 */
class NewCustomer
{
    /**
     * @var \Magento\Framework\App\RequestInterface
     */
    protected $request;

    /**
     * @var OrderRepositoryInterface
     */
    protected $orderRepository;

    /**
     * @var \Magento\Customer\Model\Session
     */
    protected $customerSession;

    /**
     * @var \Magento\Customer\Model\Account\Redirect
     */
    protected $accountRedirect;

    /**
     * @param \Magento\Framework\App\RequestInterface $request
     * @param \Magento\Sales\Api\OrderRepositoryInterface $orderRepository
     * @param \Magento\Customer\Model\Session $session
     * @param \Magento\Customer\Model\Account\Redirect $accountRedirect
     */
    public function __construct(
        \Magento\Framework\App\RequestInterface $request,
        \Magento\Sales\Api\OrderRepositoryInterface $orderRepository,
        \Magento\Customer\Model\Session $session,
        \Magento\Customer\Model\Account\Redirect $accountRedirect
    ) {
        $this->request = $request;
        $this->orderRepository = $orderRepository;
        $this->customerSession = $session;
        $this->accountRedirect = $accountRedirect;
    }

    /**
     * @param Customer $subject
     * @param callable $proceed
     * @return mixed
     * @throws \Magento\Framework\Exception\InputException
     * @throws \Magento\Framework\Exception\LocalizedException
     * @throws \Magento\Framework\Exception\State\InputMismatchException
     */
    public function aroundExecute(CreatePost $subject, callable $proceed)
    {
        if (!$this->request->getParam('redirect_to_account_dashboard')) {
            $this->accountRedirect->setRedirectCookie('nowhere');
        }

        $returnValue = $proceed();

        $customer = $this->customerSession->getCustomer();

        try {
            $order = $this->orderRepository->get(
                $this->request->getParam('order_id')
            );
            $order->getBillingAddress()->setCustomerId($customer->getId());
            $order->getShippingAddress()->setCustomerId($customer->getId());
            $order->setCustomerId($customer->getId());
            $this->orderRepository->save($order);
        } catch (\Exception $exception) {
        }

        return $returnValue;
    }
}
