<?php
/**
 * @category    Pinpoint
 * @package     Pinpoint_RegisterOnSuccess
 * @copyright   Copyright (c) 2019 Pinpoint Designs. (http://www.pinpointdesigns.co.uk)
 * @author      Mohamed Zahran <mohamed.zahran@bytology.co.uk>
 */

namespace Pinpoint\RegisterOnSuccess\Setup;

use Magento\Framework\Setup\InstallDataInterface;
use Magento\Framework\Setup\ModuleContextInterface;
use Magento\Framework\Setup\ModuleDataSetupInterface;
use Pinpoint\RegisterOnSuccess\Block\Register;

/**
 * Class InstallData
 */
class InstallData implements InstallDataInterface
{
    /**
     * @var \Magento\Cms\Model\BlockFactory
     */
    protected $blockFactory;

    /**
     * @var Magento\Cms\Model\ResourceModel\BlockFactory
     */
    protected $blockResourceFactory;

    /**
     * @param \Magento\Cms\Model\BlockFactory $blockFactory
     * @param BlockResourceFactory $blockResourceFactory
     */
    public function __construct(
        \Magento\Cms\Model\BlockFactory $blockFactory,
        \Magento\Cms\Model\ResourceModel\BlockFactory $blockResourceFactory
    ) {
        $this->blockFactory = $blockFactory;
        $this->blockResourceFactory = $blockResourceFactory;
    }

    /**
     * Installs data for a module
     *
     * @param ModuleDataSetupInterface $setup
     * @param ModuleContextInterface $context
     * @return void
     * @throws \Exception
     */
    public function install(ModuleDataSetupInterface $setup, ModuleContextInterface $context)
    {
        $blockResource = $this->createBlockResource();

        $block = $this->createBlockModel();
        $block->setIdentifier(Register::CMS_BLOCK_ONE_IDENTIFIER);
        $block->setTitle(Register::CMS_BLOCK_ONE_TITLE);
        $block->setContent('');

        $blockResource->save($block);

        unset($block);

        $block = $this->createBlockModel();
        $block->setIdentifier(Register::CMS_BLOCK_TWO_IDENTIFIER);
        $block->setTitle(Register::CMS_BLOCK_TWO_TITLE);
        $block->setContent('');

        $blockResource->save($block);
    }

    /**
     * @return \Magento\Cms\Model\Block
     */
    protected function createBlockModel()
    {
        return $this->blockFactory->create();
    }

    /**
     * @return \Magento\Cms\Model\ResourceModel\Block
     */
    protected function createBlockResource()
    {
        return $this->blockResourceFactory->create();
    }
}
